==> qtjambi-scxml-6.5.0-sources.jar: io/qt/scxml/QScxmlInvokableService.java <==
package io.qt.scxml;

import io.qt.*;


/**
 * <p>The base class for services called from state machines</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html">QScxmlInvokableService</a></p>
 */
public abstract class QScxmlInvokableService extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlInvokableService.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QScxmlInvokableService {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public java.lang.@NonNull String id(){
            return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native java.lang.String id_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public java.lang.@NonNull String name(){
            return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native java.lang.String name_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public void postEvent(io.qt.scxml.@Nullable QScxmlEvent event){
            postEvent_native_QScxmlEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), event);
        }
        @QtUninvokable
        private native void postEvent_native_QScxmlEvent_ptr(long __this__nativeId, io.qt.scxml.QScxmlEvent event);
        
        
        @Override
        @QtUninvokable
        public boolean start(){
            return start_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native boolean start_native(long __this__nativeId);
        
    }
    
    
    public QScxmlInvokableService(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine, io.qt.scxml.@Nullable QScxmlInvokableServiceFactory parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parentStateMachine, parent);
    }
    
    private native static void initialize_native(QScxmlInvokableService instance, io.qt.scxml.QScxmlStateMachine parentStateMachine, io.qt.scxml.QScxmlInvokableServiceFactory parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #parentStateMachine()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.scxml.@Nullable QScxmlStateMachine getParentStateMachine() {
        return parentStateMachine();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#parentStateMachine-prop">QScxmlInvokableService::parentStateMachine()const</a></p>
     */
    @QtPropertyReader(name="parentStateMachine")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine(){
        return parentStateMachine_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlStateMachine parentStateMachine_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #id()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getId() {
        return id();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#id-prop">QScxmlInvokableService::id()const</a></p>
     */
    @QtPropertyReader(name="id")
    @QtPropertyConstant
    @QtUninvokable
    public abstract java.lang.@NonNull String id();
    
    @QtUninvokable
    private native java.lang.String id_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #name()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getName() {
        return name();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#name-prop">QScxmlInvokableService::name()const</a></p>
     */
    @QtPropertyReader(name="name")
    @QtPropertyConstant
    @QtUninvokable
    public abstract java.lang.@NonNull String name();
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#postEvent">QScxmlInvokableService::postEvent(QScxmlEvent*)</a></p>
     */
    @QtUninvokable
    public abstract void postEvent(io.qt.scxml.@Nullable QScxmlEvent event);
    
    @QtUninvokable
    private native void postEvent_native_QScxmlEvent_ptr(long __this__nativeId, io.qt.scxml.QScxmlEvent event);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#start">QScxmlInvokableService::start()</a></p>
     */
    @QtUninvokable
    public abstract boolean start();
    
    @QtUninvokable
    private native boolean start_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QScxmlInvokableService(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-scxml-6.5.3-sources.jar: io/qt/scxml/QScxmlInvokableService.java <==
package io.qt.scxml;

import io.qt.*;


/**
 * <p>The base class for services called from state machines</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qscxmlinvokableservice.html">QScxmlInvokableService</a></code></p>
 */
public abstract class QScxmlInvokableService extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QScxmlInvokableService.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QScxmlInvokableService {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public java.lang.@NonNull String id(){
            return id_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native java.lang.String id_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public java.lang.@NonNull String name(){
            return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native java.lang.String name_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public void postEvent(io.qt.scxml.@Nullable QScxmlEvent event){
            postEvent_native_QScxmlEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), event);
        }
        @QtUninvokable
        private native void postEvent_native_QScxmlEvent_ptr(long __this__nativeId, io.qt.scxml.QScxmlEvent event);
        
        
        @Override
        @QtUninvokable
        public boolean start(){
            return start_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native boolean start_native(long __this__nativeId);
        
    }
    
    
    /**
     * <p>See <code>QScxmlInvokableService::<wbr>QScxmlInvokableService(QScxmlStateMachine*,<wbr>QScxmlInvokableServiceFactory*)</code></p>
     */
    public QScxmlInvokableService(io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine, io.qt.scxml.@Nullable QScxmlInvokableServiceFactory parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parentStateMachine, parent);
    }
    
    private native static void initialize_native(QScxmlInvokableService instance, io.qt.scxml.QScxmlStateMachine parentStateMachine, io.qt.scxml.QScxmlInvokableServiceFactory parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#parentStateMachine-prop">QScxmlInvokableService::<wbr>parentStateMachine()const</a></code></p>
     */
    @QtPropertyReader(name="parentStateMachine")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.scxml.@Nullable QScxmlStateMachine parentStateMachine(){
        return parentStateMachine_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.scxml.QScxmlStateMachine parentStateMachine_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#id-prop">QScxmlInvokableService::<wbr>id()const</a></code></p>
     */
    @QtPropertyReader(name="id")
    @QtPropertyConstant
    @QtUninvokable
    public abstract java.lang.@NonNull String id();
    
    @QtUninvokable
    private native java.lang.String id_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#name-prop">QScxmlInvokableService::<wbr>name()const</a></code></p>
     */
    @QtPropertyReader(name="name")
    @QtPropertyConstant
    @QtUninvokable
    public abstract java.lang.@NonNull String name();
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#postEvent">QScxmlInvokableService::<wbr>postEvent(QScxmlEvent*)</a></code></p>
     */
    @QtUninvokable
    public abstract void postEvent(io.qt.scxml.@Nullable QScxmlEvent event);
    
    @QtUninvokable
    private native void postEvent_native_QScxmlEvent_ptr(long __this__nativeId, io.qt.scxml.QScxmlEvent event);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qscxmlinvokableservice.html#start">QScxmlInvokableService::<wbr>start()</a></code></p>
     */
    @QtUninvokable
    public abstract boolean start();
    
    @QtUninvokable
    private native boolean start_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QScxmlInvokableService(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Kotlin property getter. In Java use {@link #parentStateMachine()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.scxml.@Nullable QScxmlStateMachine getParentStateMachine() {
        return parentStateMachine();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #id()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getId() {
        return id();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #name()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getName() {
        return name();
    }
}
